package com.sun.corba.se.impl.interceptors;

import com.sun.corba.se.spi.ior.TaggedProfileTemplate;
import java.util.Iterator;
import org.omg.PortableInterceptor.ObjectReferenceFactory;
import org.omg.PortableInterceptor.ObjectReferenceTemplate;
import com.sun.corba.se.spi.legacy.interceptor.UnknownType;
import org.omg.IOP.TaggedComponent;
import org.omg.CORBA.Policy;
import com.sun.corba.se.impl.logging.OMGSystemException;
import com.sun.corba.se.impl.logging.InterceptorsSystemException;
import com.sun.corba.se.impl.logging.ORBUtilSystemException;
import com.sun.corba.se.spi.orb.ORB;
import com.sun.corba.se.spi.oa.ObjectAdapter;
import com.sun.corba.se.spi.legacy.interceptor.IORInfoExt;
import org.omg.PortableInterceptor.IORInfo;
import org.omg.CORBA.LocalObject;

public final class IORInfoImpl extends LocalObject implements IORInfo, IORInfoExt
{
    private static final int STATE_INITIAL = 0;
    private static final int STATE_ESTABLISHED = 1;
    private static final int STATE_DONE = 2;
    private int state;
    private ObjectAdapter adapter;
    private ORB orb;
    private ORBUtilSystemException orbutilWrapper;
    private InterceptorsSystemException wrapper;
    private OMGSystemException omgWrapper;
    
    IORInfoImpl(ObjectAdapter adapter) {
        this.state = 0;
        this.orb = adapter.getORB();
        this.orbutilWrapper = ORBUtilSystemException.get(this.orb, "rpc.protocol");
        this.wrapper = InterceptorsSystemException.get(this.orb, "rpc.protocol");
        this.omgWrapper = OMGSystemException.get(this.orb, "rpc.protocol");
        this.adapter = adapter;
    }
    
    public Policy get_effective_policy(int n) {
        this.checkState(0, 1);
        return this.adapter.getEffectivePolicy(n);
    }
    
    public void add_ior_component(TaggedComponent taggedComponent) {
        this.checkState(0);
        if (taggedComponent == null) {
            this.nullParam();
        }
        this.addIORComponentToProfileInternal(taggedComponent, this.adapter.getIORTemplate().iterator());
    }
    
    public void add_ior_component_to_profile(TaggedComponent taggedComponent, int n) {
        this.checkState(0);
        if (taggedComponent == null) {
            this.nullParam();
        }
        this.addIORComponentToProfileInternal(taggedComponent, this.adapter.getIORTemplate().iteratorById(n));
    }
    
    public int getServerPort(String s) throws UnknownType {
        this.checkState(0, 1);
        int legacyGetTransientOrPersistentServerPort = this.orb.getLegacyServerSocketManager().legacyGetTransientOrPersistentServerPort(s);
        if (legacyGetTransientOrPersistentServerPort == -1) {
            throw new UnknownType();
        }
        return legacyGetTransientOrPersistentServerPort;
    }
    
    public ObjectAdapter getObjectAdapter() {
        return this.adapter;
    }
    
    public int manager_id() {
        this.checkState(0, 1);
        return this.adapter.getManagerId();
    }
    
    public short state() {
        this.checkState(0, 1);
        return this.adapter.getState();
    }
    
    public ObjectReferenceTemplate adapter_template() {
        this.checkState(1);
        return this.adapter.getAdapterTemplate();
    }
    
    public ObjectReferenceFactory current_factory() {
        this.checkState(1);
        return this.adapter.getCurrentFactory();
    }
    
    public void current_factory(ObjectReferenceFactory currentFactory) {
        this.checkState(1);
        this.adapter.setCurrentFactory(currentFactory);
    }
    
    private void addIORComponentToProfileInternal(TaggedComponent taggedComponent, Iterator iterator) {
        com.sun.corba.se.spi.ior.TaggedComponent create = this.orb.getTaggedComponentFactoryFinder().create(this.orb, taggedComponent);
        boolean n = false;
        while (iterator.hasNext()) {
            n = true;
            ((TaggedProfileTemplate)iterator.next()).add(create);
        }
        if (n == 0) {
            throw this.omgWrapper.invalidProfileId();
        }
        return;
    }
    
    private void nullParam() {
        throw this.orbutilWrapper.nullParam();
    }
    
    private void checkState(int value) {
        if (value != this.state) {
            throw this.wrapper.badState1(new Integer(value), new Integer(this.state));
        }
        return;
    }
    
    private void checkState(int value, int value2) {
        if (value != this.state && value2 != this.state) {
            throw this.wrapper.badState2(new Integer(value), new Integer(value2), new Integer(this.state));
        }
        return;
    }
    
    void makeStateEstablished() {
        this.checkState(0);
        this.state = 1;
    }
    
    void makeStateDone() {
        this.checkState(1);
        this.state = 2;
    }
}
